Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1023)

Unified Diff: remoting/protocol/transport.h

Issue 1197853003: Add P2PDatagramSocket and P2PStreamSocket interfaces. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/protocol/stream_channel_factory.h ('k') | remoting/remoting_srcs.gypi » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/protocol/transport.h
diff --git a/remoting/protocol/transport.h b/remoting/protocol/transport.h
index 4223796a6407c551a9b69cfbd9249eabad024c0a..a065e6b4a09659f874711a570f1e82020d4053d4 100644
--- a/remoting/protocol/transport.h
+++ b/remoting/protocol/transport.h
@@ -9,15 +9,14 @@
// reliable stream connection and the other one for unreliable
// datagram connection. The Transport interface itself doesn't provide
// methods to send/receive data. Instead it creates an instance of
// net::Socket or net::SocketStream which provides access to the data
// channel. After a new transport is Initialize()'ed the Connect()
// method must be called. Connect() starts asynchronous creation and
// initialization of the connection socket that can be used later to
// send and receive data. The socket is passed to the callback
// specified in the Connect() call. The Transport object must exist
// during the whole lifetime of the connection socket. Later deletion
// of the connection socket causes teardown of the corresponding
// Transport object.
#ifndef REMOTING_PROTOCOL_TRANSPORT_H_
#define REMOTING_PROTOCOL_TRANSPORT_H_
@@ -34,15 +33,11 @@ namespace cricket {
class Candidate;
} // namespace cricket
-namespace net {
-class Socket;
-class StreamSocket;
-} // namespace net
-
namespace remoting {
namespace protocol {
class ChannelAuthenticator;
+class P2PDatagramSocket;
enum class TransportRole {
SERVER,
@@ -98,7 +93,7 @@ class Transport : public base::NonThreadSafe {
virtual void OnTransportDeleted(Transport* transport) = 0;
};
- typedef base::Callback<void(scoped_ptr<net::Socket>)> ConnectedCallback;
+ typedef base::Callback<void(scoped_ptr<P2PDatagramSocket>)> ConnectedCallback;
Transport() {}
virtual ~Transport() {}
« no previous file with comments | « remoting/protocol/stream_channel_factory.h ('k') | remoting/remoting_srcs.gypi » ('j') | no next file with comments »
@@ -9,15 +9,14 @@
// datagram connection. The Transport interface itself doesn't provide
// methods to send/receive data. Instead it creates an instance of
-// net::Socket or net::SocketStream which provides access to the data
-// channel. After a new transport is Initialize()'ed the Connect()
-// method must be called. Connect() starts asynchronous creation and
-// initialization of the connection socket that can be used later to
-// send and receive data. The socket is passed to the callback
-// specified in the Connect() call. The Transport object must exist
-// during the whole lifetime of the connection socket. Later deletion
-// of the connection socket causes teardown of the corresponding
-// Transport object.
+// P2PDatagramSocket which provides access to the data channel. After a
+// new transport is Initialize()'ed the Connect() method must be called.
+// Connect() starts asynchronous creation and initialization of the
+// connection socket that can be used later to send and receive data.
+// The socket is passed to the callback specified in the Connect() call.
+// The Transport object must exist during the whole lifetime of the
+// connection socket. Later deletion of the connection socket causes
+// teardown of the corresponding Transport object.
#ifndef REMOTING_PROTOCOL_TRANSPORT_H_
#define REMOTING_PROTOCOL_TRANSPORT_H_

Powered by Google App Engine
This is Rietveld 408576698